@@ -106,6 +106,14 @@ void safeReplaceString(char** oldstr, const gchar *newstr, MainView *mainview) {
 	}
 }
 
+const gchar *entryGetText(GtkWidget *widget) {
+#if MAEMO_VERSION_MAJOR < 5
+	return gtk_entry_get_text(GTK_ENTRY(widget));
+#else
+	return hildon_entry_get_text(HILDON_ENTRY(widget));
+#endif
+}
+
 /* record detail events */
 void callback_rec_response(GtkDialog *dialog, gint arg1, MainView *mainview) {
 	RecWindow *recwindow = NULL;
@@ -120,11 +128,16 @@ void callback_rec_response(GtkDialog *dialog, gint arg1, MainView *mainview) {
 	rec=recwindow->rec;
 	switch (arg1) {
 		case 1: /* save any changes */
-			safeReplaceString(&rec->title, gtk_entry_get_text(GTK_ENTRY(recwindow->title)), mainview);
+			safeReplaceString(&rec->title, entryGetText(recwindow->title), mainview);
+			safeReplaceString(&rec->user, entryGetText(recwindow->username), mainview);
+			safeReplaceString(&rec->password, entryGetText(recwindow->password), mainview);
+#if MAEMO_VERSION_MAJOR < 5
 			safeReplaceString(&rec->group, gtk_combo_box_get_active_text(GTK_COMBO_BOX(recwindow->group)), mainview);
-			safeReplaceString(&rec->user, gtk_entry_get_text(GTK_ENTRY(recwindow->username)), mainview);
-			safeReplaceString(&rec->password, gtk_entry_get_text(GTK_ENTRY(recwindow->password)), mainview);
 			buffer=gtk_text_view_get_buffer (GTK_TEXT_VIEW(recwindow->notes));
+#else
+			safeReplaceString(&rec->group, hildon_touch_selector_get_current_text(HILDON_TOUCH_SELECTOR(recwindow->group)), mainview);
+			buffer=hildon_text_view_get_buffer (HILDON_TEXT_VIEW(recwindow->notes));
+#endif
 			if (gtk_text_buffer_get_modified(buffer)) { /* update notes if buffer has changed */
 				gtk_text_buffer_get_start_iter (buffer, &start);
 				gtk_text_buffer_get_end_iter (buffer, &end);
