@@ -51,7 +51,8 @@ void callback_filter ( GtkAction * action, MainView *mainview );
 /* export */
 void callback_export ( GtkAction * action, MainView *mainview );
 /* grid activated */
-void callback_activate_treeView(GtkTreeView *treeView, GtkTreePath *path, MainView *mainview);
+void callback_hildon_activate_treeView(GtkTreeView *treeView, GtkTreePath *path, MainView *mainview);
+void callback_activate_treeView(GtkTreeView *treeView, GtkTreePath *path, GtkTreeViewColumn *column, MainView *mainview);
 /* record details button */
 void callback_rec_response(GtkDialog *dialog, gint arg1, MainView *mainview);
 /* hardware events */
