@@ -72,7 +72,7 @@ void close_file(MainView *mainview) {
 	mainview->file_edited=FALSE;
 	mainview->file_name=NULL;
 	GList *onrec=NULL;
-	empty_iconView(mainview);
+	empty_treeView(mainview);
 	if (recs!=NULL) {
 		unshow_rec(mainview);  /* close any open rec window */
 		onrec=g_list_first(recs);
@@ -416,6 +416,9 @@ void read_pwsafe_file(MainView* mainview) {
 	file_utf8=g_filename_to_utf8(mainview->file_name, -1, NULL, NULL, NULL);
 	mainview->pass=get_password(mainview, file_utf8);
 	g_free(file_utf8);
+	
+	// Fred manage interface
+	interface_show_state(mainview);
 
 	if (mainview->pass) {
 		GnomeVFSResult vfs_result;
@@ -438,82 +441,97 @@ void read_pwsafe_file(MainView* mainview) {
 		gnome_vfs_init();
 		/* get file info (test's file exists, and gets length into finfo) */
 		vfs_result = gnome_vfs_get_file_info(mainview->file_name, &finfo, GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
-		if (pwsafe_file_open_error(mainview, vfs_result)) return;
-		/* open file to read */
-		vfs_result = gnome_vfs_open(&handle, mainview->file_name, GNOME_VFS_OPEN_READ);
-		if (pwsafe_file_open_error(mainview, vfs_result)) return;
-		if (!testpassword(mainview, handle)) return;
-		/* read salt and iv */
-		if (!readbytes(mainview, handle, salt, sizeof(salt))) return;
-		if (!readbytes(mainview, handle, (unsigned char *) iv, sizeof(iv))) return;
-		/* generate decryption key */
-		SHA1Init(&keyHash);
-		SHA1Update(&keyHash, (unsigned char *) mainview->pass, strlen(mainview->pass));
-		SHA1Update(&keyHash, salt, sizeof(salt));
-		SHA1Final(salt, &keyHash);
-		/* initialize blowfish with the key */
-		Blowfish_Init(&blowCTX, salt, sizeof(salt));
-		
-		buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
-		if (buffer==NULL) return;
-		filetitle=buffer;
-		buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
-		if (buffer==NULL) return;
-		fileversion=buffer;
-		if (strcmp("2.0", fileversion)!=0) msgbox(mainview, "Unexpected file version (not 2.0)");
-		buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
-		mainview->preferences=buffer;
-		/* create an entry record, with everything pointing to an empty string */
-		entry=g_malloc0(sizeof(rec));
-		entry->uuid=entry->group=entry->title=entry->user=entry->notes=entry->password=NULL;
-		recs=NULL;
-		/* read and decrypt the blocks. store the settings for each one, and write them to the tree on each END */
-		buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
-		do {
-			switch (rec_type) {
-				case UUID:
-					if (buffer_len!=16) {
-						if (!uuiderr) msgbox(mainview, "file error - UUID not 16 bytes. Recreating");
-						uuiderr=TRUE;
-						g_free(buffer);
-						new_uuid(entry);
-					} else {
-						entry->uuid=buffer;
+		if (!pwsafe_file_open_error(mainview, vfs_result)) {
+			/* open file to read */
+			vfs_result = gnome_vfs_open(&handle, mainview->file_name, GNOME_VFS_OPEN_READ);
+			if (!pwsafe_file_open_error(mainview, vfs_result)) {
+				if (testpassword(mainview, handle)) {
+					/* read salt and iv */
+					if (readbytes(mainview, handle, salt, sizeof(salt))) {
+						if (readbytes(mainview, handle, (unsigned char *) iv, sizeof(iv))) {
+							/* generate decryption key */
+							SHA1Init(&keyHash);
+							SHA1Update(&keyHash, (unsigned char *) mainview->pass, strlen(mainview->pass));
+							SHA1Update(&keyHash, salt, sizeof(salt));
+							SHA1Final(salt, &keyHash);
+							/* initialize blowfish with the key */
+							Blowfish_Init(&blowCTX, salt, sizeof(salt));
+							
+							buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
+							if (buffer!=NULL) {
+								filetitle=buffer;
+								buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
+								if (buffer!=NULL) {
+									fileversion=buffer;
+									if (strcmp("2.0", fileversion)!=0) {
+										msgbox(mainview, "Unexpected file version (not 2.0)");
+									}
+									buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
+									mainview->preferences=buffer;
+									/* create an entry record, with everything pointing to an empty string */
+									entry=g_malloc0(sizeof(rec));
+									entry->uuid=entry->group=entry->title=entry->user=entry->notes=entry->password=NULL;
+									recs=NULL;
+									/* read and decrypt the blocks. store the settings for each one, and write them to the tree on each END */
+									buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
+									do {
+										switch (rec_type) {
+											case UUID:
+												if (buffer_len!=16) {
+													if (!uuiderr) {
+														msgbox(mainview, "file error - UUID not 16 bytes. Recreating");
+													}
+													uuiderr=TRUE;
+													g_free(buffer);
+													new_uuid(entry);
+												} else {
+													entry->uuid=buffer;
+												}
+												break;
+											case GROUP:
+												entry->group=buffer;
+												break;
+											case TITLE:
+												entry->title=buffer;
+												break;
+											case USER:
+												entry->user=buffer;
+												break;
+											case NOTES:
+												entry->notes=buffer;
+												break;
+											case PASSWORD:
+												entry->password=buffer;
+												break;
+											case END:
+												g_free(buffer);
+												recs=g_list_insert_sorted(recs, entry, (GCompareFunc) rec_comparer);
+												entry=g_malloc0(sizeof(rec));
+												entry->uuid=entry->group=entry->title=entry->user=entry->notes=entry->password=NULL;
+												break;
+											default: /* unknown block... just delete it and move on. */
+												if (buffer_len>0) {
+													g_free(buffer);
+												}
+										}
+										gnome_vfs_tell(handle, &filepos);
+										if (finfo.size<=filepos) {
+											break;
+										}
+										buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
+									} while (buffer!=NULL);
+									g_free(fileversion);
+									populate_treeView(mainview);
+								}
+								g_free(filetitle);
+							}
+						}
 					}
-					break;
-				case GROUP:
-					entry->group=buffer;
-					break;
-				case TITLE:
-					entry->title=buffer;
-					break;
-				case USER:
-					entry->user=buffer;
-					break;
-				case NOTES:
-					entry->notes=buffer;
-					break;
-				case PASSWORD:
-					entry->password=buffer;
-					break;
-				case END:
-					g_free(buffer);
-					recs=g_list_insert_sorted(recs, entry, (GCompareFunc) rec_comparer);
-					entry=g_malloc0(sizeof(rec));
-					entry->uuid=entry->group=entry->title=entry->user=entry->notes=entry->password=NULL;
-					break;
-				default: /* unknown block... just delete it and move on. */
-					if (buffer_len>0) g_free(buffer);
+				}
+				mainview->last_file=mainview->file_name;
+				conf_save_string(CONF_LASTFILE, mainview->last_file);
 			}
-			gnome_vfs_tell(handle, &filepos);
-			if (finfo.size<=filepos) break;
-			buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
-		} while (buffer!=NULL);
-		gnome_vfs_close(handle);
-		g_free(filetitle);
-		g_free(fileversion);
-		mainview->last_file=mainview->file_name;
-		conf_save_string(CONF_LASTFILE, mainview->last_file);
-		populate_iconView(mainview, "");
+			gnome_vfs_close(handle);
+		}
 	}
 }
