@@ -104,10 +104,17 @@ void interface_main_view_destroy( MainView *main ) {
 
 GtkWidget *show_rec_line(GtkWidget *sizer, char *label, char *txt, int row, int col) {
 	GtkWidget *textentry;
+#if MAEMO_VERSION_MAJOR < 5
 	gtk_table_attach_defaults(GTK_TABLE(sizer), gtk_label_new(label), col, col+1, row, row+1);
 	textentry=gtk_entry_new();
 	if (txt!=NULL) gtk_entry_set_text(GTK_ENTRY(textentry), txt);
 	gtk_table_attach_defaults(GTK_TABLE(sizer), textentry, col+1,col+2, row, row+1);
+#else
+	textentry=hildon_entry_new(HILDON_SIZE_AUTO);
+	hildon_entry_set_placeholder(HILDON_ENTRY(textentry), label);
+	if (txt!=NULL) hildon_entry_set_text(HILDON_ENTRY(textentry), txt);
+	gtk_table_attach_defaults(GTK_TABLE(sizer), textentry, col,col+2, row, row+1);
+#endif
 	return textentry;
 }
 
@@ -142,7 +149,11 @@ gboolean fillCombo (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, G
 	
 	gtk_tree_model_get(model, iter, LABEL_COLUMN, &label, DATA_COLUMN, &data,  -1);
 	if (data == NULL && label != NULL) {
+#if MAEMO_VERSION_MAJOR < 5
 		gtk_combo_box_append_text(GTK_COMBO_BOX(combo), label);
+#else
+		hildon_touch_selector_append_text(HILDON_TOUCH_SELECTOR(combo), label);
+#endif
 	}
 	return FALSE;
 }
@@ -166,25 +177,42 @@ void show_rec(MainView *main, rec *r) {
 	rec_win->title=show_rec_line(sizer, _("Title"), r->title, 0, 0);
 //	rec_win->group=show_rec_line(sizer, "Group", r->group, 0, 2);
 	// Change group entry to ComboBox with Entry
+#if MAEMO_VERSION_MAJOR < 5
 	gtk_table_attach_defaults(GTK_TABLE(sizer), gtk_label_new(_("Group")), 2, 3, 0, 1);
 	rec_win->group=gtk_combo_box_entry_new_text();
 	if (r->group!=NULL) {
 		gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(rec_win->group))), r->group);
 	}
 	gtk_table_attach_defaults(GTK_TABLE(sizer), rec_win->group, 3, 4, 0, 1);
+#else
+	rec_win->group=hildon_touch_selector_entry_new_text();
+	hildon_entry_set_placeholder(hildon_touch_selector_entry_get_entry(HILDON_TOUCH_SELECTOR_ENTRY(rec_win->group)), _("Group"));
+	if (r->group!=NULL) {
+		hildon_entry_set_text(hildon_touch_selector_entry_get_entry(HILDON_TOUCH_SELECTOR_ENTRY(rec_win->group)), r->group);
+	}
+	gtk_table_attach_defaults(GTK_TABLE(sizer), rec_win->group, 2, 4, 0, 1);
+#endif
 	// Fill the combo
 	gtk_tree_model_foreach(GTK_TREE_MODEL(main->store), (GtkTreeModelForeachFunc) fillCombo, (gpointer) rec_win->group);
 	
 	rec_win->username=show_rec_line(sizer, _("Username"), r->user, 1, 0);
 	rec_win->password=show_rec_line(sizer, _("Password"), r->password, 1, 2);
 
+#if MAEMO_VERSION_MAJOR < 5
 	rec_win->notes=gtk_text_view_new();
 	buffer=gtk_text_view_get_buffer(GTK_TEXT_VIEW(rec_win->notes));
-	if (r->notes!=NULL) gtk_text_buffer_set_text (buffer, r->notes, -1);
-	gtk_text_buffer_set_modified (buffer, FALSE);
 	scrollwindow=gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrollwindow), GTK_SHADOW_IN);
+#else
+	rec_win->notes= hildon_text_view_new();
+	hildon_text_view_set_placeholder(HILDON_TEXT_VIEW(rec_win->notes), _("Notes"));
+	buffer=hildon_text_view_get_buffer(HILDON_TEXT_VIEW(rec_win->notes));
+	scrollwindow=hildon_pannable_area_new();
+#endif
+	if (r->notes!=NULL) gtk_text_buffer_set_text (buffer, r->notes, -1);
+	gtk_text_buffer_set_modified (buffer, FALSE);
 	gtk_container_add (GTK_CONTAINER (scrollwindow), rec_win->notes);
+
 	gtk_table_attach(GTK_TABLE(sizer), scrollwindow, 0, 4, 2, 5, GTK_FILL, GTK_FILL, 0, 0);
 	gtk_container_add (GTK_CONTAINER (GTK_DIALOG(rec_win->dialog)->vbox), sizer);
 	gtk_widget_show_all (rec_win->dialog);
@@ -487,8 +515,12 @@ void interface_set_rec_editable(RecWindow* rec_win, gboolean editable) {
 		gtk_widget_show(GTK_WIDGET(rec_win->edit_button));
 	}
 	gtk_editable_set_editable(GTK_EDITABLE(rec_win->title), editable);
+#if MAEMO_VERSION_MAJOR < 5
 	// Group is a comboBoxEdit
 	gtk_editable_set_editable(GTK_EDITABLE(gtk_bin_get_child(GTK_BIN(rec_win->group))), editable);
+#else
+	gtk_editable_set_editable(GTK_EDITABLE(hildon_touch_selector_entry_get_entry(HILDON_TOUCH_SELECTOR(rec_win->group))), editable);
+#endif
 	gtk_editable_set_editable(GTK_EDITABLE(rec_win->username), editable);
 	gtk_editable_set_editable(GTK_EDITABLE(rec_win->password), editable);
 	gtk_text_view_set_editable(GTK_TEXT_VIEW(rec_win->notes), editable);
